==> version-1.1.1.tar.gz: svm_toolkit/test/evaluator_test.rb <==
require 'svm_toolkit'
require 'minitest/autorun'

include SvmToolkit

describe Evaluator do 

  it "must correctly evaluate individual and comparative performance by accuracy" do
    performance = Evaluator::OverallAccuracy.new
    performance.value.must_equal 0.0
    performance.add_result(0, 0)
    performance.value.must_equal 100.0
    performance.add_result(1, 0)
    performance.value.must_equal 50.0

    performance2 = Evaluator::OverallAccuracy.new
    performance.better_than?(performance2).must_equal true
    performance2.add_result(1, 1)
    performance2.add_result(1, 1)
    performance.better_than?(performance2).must_equal false
  end

  it "must correctly compute geometric mean" do
    performance = Evaluator::GeometricMean.new
    performance.value.must_equal 0.0
    performance.add_result(0, 0)
    performance.value.must_equal 1.0
    performance.add_result(0, 1)
    performance.add_result(1, 1)
    performance.value.must_be_within_delta 0.707, 0.01
    performance.add_result(1, 1)
    performance.add_result(1, 0)
    performance.value.must_be_within_delta 0.577, 0.01
  end

  it "must correctly compute class precision" do
    performance1 = Evaluator::ClassPrecision(0).new
    performance1.add_result(0, 0)
    performance1.add_result(0, 0)
    performance1.add_result(0, 0)
    performance1.add_result(0, 1)
    performance1.add_result(1, 0)
    performance1.add_result(1, 0)
    performance1.add_result(1, 1)
    # 3 correct out of 4 0s actually output
    performance1.value.must_equal 0.75
  end

  it "must correctly compute class precision" do
    performance2 = Evaluator::ClassPrecision(1).new
    performance2.add_result(0, 0)
    performance2.add_result(0, 0)
    performance2.add_result(0, 0)
    performance2.add_result(0, 1)
    performance2.add_result(1, 0)
    performance2.add_result(1, 0)
    performance2.add_result(1, 1)
    # 2 correct out of 3 1s actually output
    performance2.value.must_be_within_delta 0.333333, 0.001
  end

  it "must correctly compute class recall" do
    performance1 = Evaluator::ClassRecall(0).new
    performance1.add_result(0, 0)
    performance1.add_result(0, 0)
    performance1.add_result(0, 0)
    performance1.add_result(0, 1)
    performance1.add_result(1, 0)
    performance1.add_result(1, 0)
    performance1.add_result(1, 1)
    # 3 correct out of the 5 predicted 0s
    performance1.value.must_equal 0.6
  end

  it "must correctly compute class recall" do
    performance2 = Evaluator::ClassRecall(1).new
    performance2.add_result(0, 0)
    performance2.add_result(0, 0)
    performance2.add_result(0, 0)
    performance2.add_result(0, 1)
    performance2.add_result(1, 0)
    performance2.add_result(1, 0)
    performance2.add_result(1, 1)
    # 1 correct out of the 2 predicted 1s
    performance2.value.must_equal 0.5
  end

  it "must compute matthews correlation coefficient" do
    performance = Evaluator::MatthewsCorrelationCoefficient(1).new
    performance.add_result(0, 0)
    performance.value.nan?.must_equal true
    performance.add_result(0, 1)
    performance.value.nan?.must_equal true
    performance.add_result(1, 0)
    performance.value.must_equal -0.5
    performance.add_result(1, 1)
    performance.value.must_equal 0.0
    performance.add_result(1, 1)
    performance.value.must_be_within_delta 0.167, 0.001
    performance.add_result(0, 0)
    performance.value.must_be_within_delta 0.333, 0.001
  end
end

==> version-1.1.6.tar.gz: svm_toolkit/test/evaluator_test.rb <==
require 'svm-toolkit'
require 'minitest/autorun'

include SvmToolkit

describe Evaluator do 

  it "must correctly evaluate individual and comparative performance by accuracy" do
    performance = Evaluator::OverallAccuracy.new
    performance.value.must_equal 0.0
    performance.add_result(0, 0)
    performance.value.must_equal 100.0
    performance.add_result(1, 0)
    performance.value.must_equal 50.0

    performance2 = Evaluator::OverallAccuracy.new
    performance.better_than?(performance2).must_equal true
    performance2.add_result(1, 1)
    performance2.add_result(1, 1)
    performance.better_than?(performance2).must_equal false
  end

  it "must correctly compute geometric mean" do
    performance = Evaluator::GeometricMean.new
    performance.value.must_equal 1.0
    performance.add_result(0, 0)
    performance.value.must_equal 1.0
    performance.add_result(0, 1)
    performance.add_result(1, 1)
    performance.value.must_be_within_delta 0.707, 0.01
    performance.add_result(1, 1)
    performance.add_result(1, 0)
    performance.value.must_be_within_delta 0.577, 0.001
  end

  it "must correctly compute class precision" do
    performance1 = Evaluator::ClassPrecision(0).new
    performance1.add_result(0, 0)
    performance1.add_result(0, 0)
    performance1.add_result(0, 0)
    performance1.add_result(0, 1)
    performance1.add_result(1, 0)
    performance1.add_result(1, 0)
    performance1.add_result(1, 1)
    # 3 correct out of 5 predicted 0s 
    performance1.value.must_be_within_delta 0.6, 0.001
  end

  it "must correctly compute class precision" do
    performance2 = Evaluator::ClassPrecision(1).new
    performance2.add_result(0, 0)
    performance2.add_result(0, 0)
    performance2.add_result(0, 0)
    performance2.add_result(0, 1)
    performance2.add_result(1, 0)
    performance2.add_result(1, 0)
    performance2.add_result(1, 1)
    # 1 correct out of 2 predicted 1s
    performance2.value.must_be_within_delta 0.5, 0.001
  end

  it "must correctly compute class recall" do
    performance1 = Evaluator::ClassRecall(0).new
    performance1.add_result(0, 0)
    performance1.add_result(0, 0)
    performance1.add_result(0, 0)
    performance1.add_result(0, 1)
    performance1.add_result(1, 0)
    performance1.add_result(1, 0)
    performance1.add_result(1, 1)
    # 3 correct out of the 4 actual 0s
    performance1.value.must_be_within_delta 0.75, 0.001
  end

  it "must correctly compute class recall" do
    performance2 = Evaluator::ClassRecall(1).new
    performance2.add_result(0, 0)
    performance2.add_result(0, 0)
    performance2.add_result(0, 0)
    performance2.add_result(0, 1)
    performance2.add_result(1, 0)
    performance2.add_result(1, 0)
    performance2.add_result(1, 1)
    # 1 correct out of the 3 actual 1s
    performance2.value.must_be_within_delta 0.333, 0.001
  end

  it "must compute matthews correlation coefficient" do
    performance = Evaluator::MatthewsCorrelationCoefficient(1).new
    performance.add_result(0, 0)
    performance.value.must_equal 0.0
    performance.add_result(0, 1)
    performance.value.must_equal 0.0
    performance.add_result(1, 0)
    performance.value.must_equal -0.5
    performance.add_result(1, 1)
    performance.value.must_equal 0.0
    performance.add_result(1, 1)
    performance.value.must_be_within_delta 0.167, 0.001
    performance.add_result(0, 0)
    performance.value.must_be_within_delta 0.333, 0.001
  end
end
